#region Using directives
using System.Drawing;
using Perception.Sheets;
#endregion

namespace CSI_Acquisition
{
    /// <summary>
    /// Sheet Information provider class to provide sheet information
    /// </summary>
    public class SheetControlInfoProvider : ISheetInformationProvider
    {
        #region ISheetInformationProvider Members
        /// <summary>
        /// Get the sheet name.
        /// </summary>
        public string Name
        {
            get
            {
                return Properties.Resources.IDS_USERNAME;
            }
        }

        /// <summary>
        /// Get the sheet icon.
        /// </summary>
        public Icon Icon
        {
            get
            {
                return Properties.Resources.SheetIcon;
            }
        }

        /// <summary>
        /// Used when sheet is not manually creatable, to determine its default tab-position in Perception
        /// </summary>
        public int PreferredSheetIndex
        {
            get
            {
                return -1;
            }
        }

        /// <summary>
        /// Returns if the sheet is manually creatable.
        /// </summary>
        /// <remarks>
        /// Sheets that are manually creatable, are not automatically created when the application starts, 
        /// but can be added manually. They are created when loading a VWB that contains them. 
        /// </remarks>
        public ManuallyCreateType ManuallyCreatable
        {
            get
            {
                return ManuallyCreateType.NotManuallyCreatable;
            }
        }
        #endregion
    }
}